==> portmanager-0.2.9.tar.gz: portmanager-0.2.9/libMG/src/libMG.h <==
/************************************************************************/
/*	Copyright (C) 2004  Michael C. Shultz				*/
/*									*/
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License, or (at*/
/* your option) any later version.					*/
/*									*/
/* This program is distributed in the hope that it will be useful,	*/
/* but WITHOUT ANY WARRANTY; without even the implied warranty of	*/
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	*/
/* GNU General Public License for more details. 			*/
/*									*/
/* You should have received a copy of the GNU General Public License	*/
/* along with this program; if not, write to the Free Software		*/
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA		*/
/*  02111-1307, USA.							*/
/* 									*/
/* Michael C. Shultz							*/
/* ringworm01@gmail.com							*/
/* Box 3238 Landers, CA 92285						*/
/************************************************************************/

/*
	$Author: mike $
	$Revision: 1.3 $
	$Date: 2005/02/22 21:40:41 $
	$Id: libMG.h,v 1.3 2005/02/22 21:40:41 mike Exp $
	$Log: libMG.h,v $
	Revision 1.3  2005/02/22 21:40:41  mike
	Added feedback in xterm titlebar about percent complete.
	Cleaned up Makefile messages
	
	
*/	

#ifndef	__LIBMG_H__
#define __LIBMG_H__	1

#ifndef __errno__
extern	int	errno;
#define __errno__	1
#endif

#include	<assert.h>
#include	<dirent.h>
#include	<stdarg.h>
#include	<signal.h>
#include	<stdio.h>
#include	<stdlib.h>
#include	<string.h>
#include	<sys/stat.h>
#include	<sys/time.h>
#include	<sys/types.h>
#include	<sys/wait.h>
#include	<sysexits.h>
#include	<unistd.h>

#include	<sys/resource.h>

#define	CLASS_TYPE_DB	1
#define	CLASS_TYPE_DIR	2
#define	CR		13
#define	DEBUG_MGdb	0
#define	DEBUG_MGdir	0
#define	KEY_ENTER	10
#define	KEY_N		78
#define	KEY_SPACE	32
#define	KEY_X		88
#define	KEY_n		110
#define	KEY_x		120
#define	LINEFEED	10
#define	MAXENTRIES	4096	/* max directory records for MGdirCreate */
#define	MAXPARAMETERS	256
#define	SPACE		32
#define	TAB		9

#define	SINGLE_LINES	"------------------------------------------------------------------------"
#define	DOUBLE_LINES	"========================================================================"

typedef	struct classDb	classDb; 
typedef	struct classDir	classDir; 

/***********************************
MACROS
************************************/

#define MGmSetString( var, string )				\
	errorCode	= 0;					\
	var	= ( char* )malloc(strlen( string ) + 1 );	\
	if( !var )						\
	{							\
		errorCode	= 1;				\
	}							\
	else							\
	{							\
		var[0]	= 0;					\
		strncpy( var, string, strlen(string)+1 );	\
	}

char*			MGdbGet(classDb* db, int recordIdx, char* fieldName );
char*			MGdbSeek( classDb* db, char* fieldName, char* keyValue, char* returnField );
classDb*		MGdbCreate( char* dbFileName, ... );
classDb*		MGdbDelete(classDb* db, int recordIdx );
classDb*		MGdbOpen( char* dbFileName );	
int			MGdbAdd(classDb* db, ...);
int			MGdbDestroy(classDb* db);
int			MGdbGetRecno(classDb* db );
int			MGdbGetRecordQty(classDb* db);
int			MGdbGoTop(classDb* db);
int			MGdbRead( classDb* db );

char*			MGdirGet(classDir* dir);
classDir*		MGdirCreate( int mode, char* path );
int			MGdirDestroy(classDir* dir);
int			MGdirSkip(classDir* dir);
int			MGdirTest(classDir* dir);

char*			MGrIntToString( int );
int			MGrFileSize( char* );
int			MGrIfFileExist( char* );
int			MGrInStringSwap( char* originalString, char* oldString, char* newString );
int			MGrStripComment( char*, char );
unsigned long int	MGrFileTime( char* );

#endif

==> portmanager-0.3.4.tar.gz: portmanager-0.3.4/libMG/src/libMG.h <==
/************************************************************************/
/*	Copyright (C) 2004  Michael C. Shultz				*/
/*									*/
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License, or (at*/
/* your option) any later version.					*/
/*									*/
/* This program is distributed in the hope that it will be useful,	*/
/* but WITHOUT ANY WARRANTY; without even the implied warranty of	*/
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	*/
/* GNU General Public License for more details. 			*/
/*									*/
/* You should have received a copy of the GNU General Public License	*/
/* along with this program; if not, write to the Free Software		*/
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA		*/
/*  02111-1307, USA.							*/
/* 									*/
/* Michael C. Shultz							*/
/* ringworm01@gmail.com							*/
/* Box 3238 Landers, CA 92285						*/
/************************************************************************/

/*
	$Author: mike $
	$Revision: 1.3 $
	$Date: 2005/02/22 21:40:41 $
	$Id: libMG.h,v 1.3 2005/02/22 21:40:41 mike Exp $
	$Log: libMG.h,v $
	Revision 1.3  2005/02/22 21:40:41  mike
	Added feedback in xterm titlebar about percent complete.
	Cleaned up Makefile messages
	
	
*/	

#ifndef	__LIBMG_H__
#define __LIBMG_H__	1

#ifndef __errno__
extern	int	errno;
#define __errno__	1
#endif

#include	<assert.h>
#include	<dirent.h>
#include	<stdarg.h>
#include	<signal.h>
#include	<stdio.h>
#include	<stdlib.h>
#include	<string.h>
#include	<sys/stat.h>
#include	<sys/time.h>
#include	<sys/types.h>
#include	<sys/wait.h>
#include	<sysexits.h>
#include	<unistd.h>

#include	<sys/resource.h>

#define	KEY_A		65
#define	KEY_a		97
#define	CLASS_TYPE_DB	1
#define	CLASS_TYPE_DIR	2
#define	CR		13
#define	DEBUG_MGdb	0
#define	DEBUG_MGdir	0
#define	KEY_ENTER	10
#define	KEY_N		78
#define	KEY_SPACE	32
#define	KEY_X		88
#define	KEY_Y		89
#define	KEY_n		110
#define	KEY_x		120
#define	LINEFEED	10
#define	MAXENTRIES	4096	/* max directory records for MGdirCreate */
#define	MAXPARAMETERS	256
#define	SPACE		32
#define	TAB		9
#define KEY_y		121

#define	SINGLE_LINES	"------------------------------------------------------------------------"
#define	DOUBLE_LINES	"========================================================================"

typedef	struct classDb	classDb; 
typedef	struct classDir	classDir; 

/***********************************
MACROS
************************************/

#define MGmSetString( var, string )				\
	errorCode	= 0;					\
	var	= (char*)calloc( strlen( string ) + 1, 1 );	\
	if( !var )						\
	{							\
		errorCode	= 1;				\
	}							\
	else							\
	{							\
		strcat( var, string );	\
	}

char*			MGdbGet(classDb* db, int recordIdx, char* fieldName );
char*			MGdbSeek( classDb* db, char* fieldName, char* keyValue, char* returnField, char* exact );
classDb*		MGdbCreate( char* dbFileName, ... );
classDb*		MGdbOpen( char* dbFileName );	
int			MGdbAdd(classDb* db, ...);
classDb*		MGdbDelete(classDb* db, int recordIdx );
int			MGdbDestroy(classDb* db);
int			MGdbGetRecno(classDb* db );
int			MGdbGetRecordQty(classDb* db);
int			MGdbGoTop(classDb* db);
int			MGdbRead( classDb* db );

char*			MGdirGet(classDir* dir);
classDir*		MGdirCreate( int mode, char* path );
int			MGdirDestroy(classDir* dir);
int			MGdirSkip(classDir* dir);
int			MGdirTest(classDir* dir);

char*			MGrIntToString( int );
int			MGrFileSize( char* );
int			MGrIfFileExist( char* );
int			MGrInStringSwap( char* originalString, char* oldString, char* newString );
int			MGrStripComment( char*, char );
unsigned long int	MGrFileTime( char* );

#endif
